@@ -56,14 +56,14 @@ class AppiumLibrary(
         """AppiumLibrary can be imported with optional arguments.
 
         `run_on_failure` specifies the name of a keyword (from any available
-        libraries) to execute when a Selenium2Library keyword fails. By default
+        libraries) to execute when a AppiumLibrary keyword fails. By default
         `Capture Page Screenshot` will be used to take a screenshot of the current page.
-        Using the value "Nothing" will disable this feature altogether. See
+        Using the value `No Operation` will disable this feature altogether. See
         `Register Keyword To Run On Failure` keyword for more information about this
         functionality.
 
         Examples:
-        | Library | AppiumLibrary | run_on_failure=Nothing | # Sets default timeout to 10 seconds and does nothing on failure           |
+        | Library | AppiumLibrary | run_on_failure=No Operation | # Sets default timeout to 10 seconds and does nothing on failure           |
         """
         for base in AppiumLibrary.__bases__:
             base.__init__(self)
